/*
   See Section 7.4 of the textbook.
*/

public class SortingMethods
{
   /**
      This method returns a reference to an array of the
      specified size filled with random integers between
      the values of 1 and range.
   */
   public static int[] randomArray(int size, int range)
   {
      int[] outputArray = new int[size];

      for(int i = 0; i < size; i++)
      {
         outputArray[i] = (int)Math.floor( range*Math.random() )+1;
      }

      // return a reference to the array named outputArray
      return outputArray;
   }



   /**
      This method sorts an array but it returns the sorted array
      as a new array object instead of re-ordering the items in
      the array named inputArray.

      This method uses the sortInPlace() method (see below) as
      a helper method.
   */
   public static int[] sort(int[] inputArray)
   {
      // create a new array that will hold the sorted results
      int[] sortedArray = new int[inputArray.length];

      // copy the contents of inputArray into the new array
      for(int i = 0; i < inputArray.length; i++)
         sortedArray[i] = inputArray[i];

      // sort the new array
      sortInPlace(sortedArray);

      // return a reference to the array named sortedArray
      return sortedArray;
   }


   /**
      This method uses selection sort to sort the input array.
      See pages 538 - 542 of the textbook.
   */
   public static void sortInPlace(int[] inputArray)
   {
      for (int index = 0; index < inputArray.length - 1; index++)
      {
         //Place the correct value in a[index]:
         int indexOfNextSmallest = indexOfSmallest(index, inputArray);
         interchange(index,indexOfNextSmallest, inputArray);
         // a[0] <= a[1] <=...<= a[index] and these are the smallest
         // of the original array elements. The remaining positions
         // contain the rest of the original array elements.
      }
   }


   /**
      Helper method for sorting methods.

      Returns the index of the smallest value among
      a[startIndex], a[startIndex+1], ... a[a.length - 1]
   */
   private static int indexOfSmallest(int startIndex, int[] a)
   {
      int min = a[startIndex];
      int indexOfMin = startIndex;
      for (int index = startIndex + 1; index < a.length; index++)
         if (a[index] < min)
         {
            min = a[index];
            indexOfMin = index;
            //min is smallest of a[startIndex] through a[index]
         }
      return indexOfMin;
   }


   /**
      Another helper method for sorting methods.

      Precondition: i and j are legal indices for the array a.
      Postcondition: Values of a[i] and a[j] have been interchanged.
   */
   private static void interchange(int i, int j, int[] a)
   {
      int temp = a[i];
      a[i] = a[j];
      a[j] = temp; //original value of a[i]
   }

}//SortingMethods
